sdm: Add support to turn on/off destination scalar using property

Change-Id: I7568593bc740cc514923e2f0cc48f6476dfcc096
CRs-Fixed: 2130384
diff --git a/sdm/libs/core/drm/hw_info_drm.cpp b/sdm/libs/core/drm/hw_info_drm.cpp
index 8c08451..626cb40 100644
--- a/sdm/libs/core/drm/hw_info_drm.cpp
+++ b/sdm/libs/core/drm/hw_info_drm.cpp
@@ -209,9 +209,15 @@
   GetHWPlanesInfo(hw_resource);
   GetWBInfo(hw_resource);
 
-  // Disable destination scalar count to 0 if extension library is not present
+  // Disable destination scalar count to 0 if extension library is not present or disabled
+  // through property
+  int value = 0;
+  bool disable_dest_scalar = false;
+  if (Debug::Get()->GetProperty("sdm.debug.disable_dest_scalar", &value) == kErrorNone) {
+    disable_dest_scalar = (value == 1);
+  }
   DynLib extension_lib;
-  if (!extension_lib.Open("libsdmextension.so")) {
+  if (!extension_lib.Open("libsdmextension.so") || disable_dest_scalar) {
     hw_resource->hw_dest_scalar_info.count = 0;
   }